@@ -337,9 +337,11 @@ class System(base.ResourceBase):
             if not http_boot_uri:
                 # This should clear out any old entries, as no URI translates
                 # to the intent of "use whatever the dhcp server says".
-                data['Boot']['HttpBootUri'] = None
+                http_boot_uri = None
+
+            if (settings_resp and "HttpBootUri" in settings_boot_section):
+                settings_data['Boot']['HttpBootUri'] = http_boot_uri
             else:
-                # Explicitly set the URI.
                 data['Boot']['HttpBootUri'] = http_boot_uri
         elif not http_boot_uri:
             # We're not doing boot from URL, we should cleanup any setting
@@ -507,9 +509,21 @@ class System(base.ResourceBase):
         :raises: MissingAttributeError if '@odata.id' field is missing.
         :returns: A list of `Manager` instances
         """
-        paths = utils.get_sub_resource_path_by(
-            self, ["Links", "ManagedBy"], is_collection=True)
-
+        try:
+            paths = utils.get_sub_resource_path_by(
+                self, ["Links", "ManagedBy"], is_collection=True)
+        except exceptions.MissingAttributeError as exc_orig:
+            LOG.warning('Unable to find ManagedBy attribute for System %s, '
+                        'retrying with Managers attribute', self.identity)
+            try:
+                paths = utils.get_sub_resource_path_by(
+                    self, ["Links", "Managers"], is_collection=True)
+            except exceptions.MissingAttributeError:
+                LOG.error('Both ManagedBy and Managers attributes missing for '
+                          'System %s, aborting', self.identity)
+                # NOTE(janders) last_error may record only Managers and not
+                # ManagedBy MissingAttributeError with this approach
+                raise exc_orig
         return [manager.Manager(self._conn, path,
                                 redfish_version=self.redfish_version,
                                 registries=self.registries, root=self.root)
